searchData={"items":[{"type":"module","title":"ExImageInfo","doc":"ExImageInfo is an Elixir library to parse images (binaries) and get the dimensions (size), detected mime-type and overall validity for a set of image formats. Main module to parse a binary and get if it seems to be an image (validity), the mime-type (and variant detected) and the dimensions of the image, based on a specific image format.\n\nIt has convention functions to guess the type of an image\nby trying the formats supported by the library.","ref":"ExImageInfo.html"},{"type":"module","title":"Main features - ExImageInfo","doc":"- Check the validity of binary by providing a specific image format*.\n- Guess the validity of an image*.\n- Get the mime-type and variant type by providing a specific format.\n- Guess the mime-type and variant type of an image.\n- Get the dimensions of an image by providing a specific format.\n- Guess the dimensions of an image.\n\n*Note: both cases as a general overview (partially checked).","ref":"ExImageInfo.html#module-main-features"},{"type":"module","title":"Formats - ExImageInfo","doc":"Supported formats (image type to be parsed as):\n- `:bmp`\n- `:gif`\n- `:ico` (new in `v0.2.0`)\n- `:jpeg`\n- `:jpg` (alias of `jpeg` in `v0.2.3`)\n- `:jp2` (new in `v0.2.0`)\n- `:png`\n- `:pnm` (new in `v0.2.0`)\n- `:psd`\n- `:tiff`\n- `:webp` (VP8X animated in `v0.2.4`)","ref":"ExImageInfo.html#module-formats"},{"type":"module","title":"Mime-types and Variants - ExImageInfo","doc":"The image variant type is an invented string to identify the\ntype of format recognized by this library (more specific than the\nmime-type).\n\nEach mime-type can be linked to at least one variant type:\n\n| mime-type                 | variant type | description        |\n| ------------------------- | ------------ | ------------------ |\n| `image/bmp`               | `BMP`        |                    |\n| `image/gif`               | `GIF87a`     | 87a gif spec       |\n| `image/gif`               | `GIF89a`     | 89a gif spec       |\n| `image/x-icon`            | `ICO`        |                    |\n| `image/jpeg`              | `baseJPEG`   | baseline JPEG      |\n| `image/jpeg`              | `progJPEG`   | progressive JPEG   |\n| `image/jp2`               | `JP2`        | JPEG2000           |\n| `image/png`               | `PNG`        |                    |\n| `image/x-portable-anymap` | `PNMpbm`     | Portable BitMap    |\n| `image/x-portable-anymap` | `PNMpgm`     | Portable GrayMap   |\n| `image/x-portable-anymap` | `PNMppm`     | Portable PixMap    |\n| `image/psd`               | `PSD`        |                    |\n| `image/tiff`              | `TIFFII`     | II variant         |\n| `image/tiff`              | `TIFFMM`     | MM variant         |\n| `image/webp`              | `webpVP8`    | lossy              |\n| `image/webp`              | `webpVP8L`   | lossless           |\n| `image/webp`              | `webpVP8X`   | animated           |\n\nThe variant type is created just to provide a bit more of information\nfor every image format (if applicable).\n\n*Note*: `:ico` returns the dimensions of the largest image contained (not the first found).\n\nThe guessing functions try to detect the format of the binary by testing every available type based on its global usage (popularity, [usage of image file formats](https://w3techs.com/technologies/overview/image_format/all), but still keeping the `:png` as the first one):\n- `:png`, `:jpeg`, `:gif`, `:bmp`, `:ico`, `:tiff`, `:webp`, `:psd`, `:jp2`, `:pnm`","ref":"ExImageInfo.html#module-mime-types-and-variants"},{"type":"function","title":"ExImageInfo.info/1","doc":"Gets the mime-type, variant-type and dimensions (width, height) for the given image binary (*guessed* version of `ExImageInfo.info/2`).\n\nPossible [Mime-types and Variants](#module-mime-types-and-variants) to be returned.\n\nReturns a 4-item tuple with the mime-type, width, height and the variant type when the binary matches, `nil` otherwise.","ref":"ExImageInfo.html#info/1"},{"type":"function","title":"Examples - ExImageInfo.info/1","doc":"iex> ExImageInfo.info  >\n    nil\n    iex> ExImageInfo.info  >\n    {\"image/psd\", 12, 10, \"PSD\"}\n\nUsually it is used as:\n\n    ExImageInfo.info File.read!(\"path/to/image.unknown\")\n    # {\"image/tiff\", 128, 256, \"TIFFMM\"}\n\n    webp_full_binary |> ExImageInfo.info\n    # {\"image/webp\", 20, 100, \"webpVP8\"}","ref":"ExImageInfo.html#info/1-examples"},{"type":"function","title":"ExImageInfo.info/2","doc":"Gets the mime-type, variant-type and dimensions (width, height) for the given image format and binary.\n\nPossible [Mime-types and Variants](#module-mime-types-and-variants) to be returned.\n\nValid [formats](#module-formats) to be used.\n\nReturns a 4-item tuple with the mime-type, width, height and the variant type when the binary matches, `nil` otherwise.","ref":"ExImageInfo.html#info/2"},{"type":"function","title":"Examples - ExImageInfo.info/2","doc":"`89 50 4E 47 0D 0A 1A 0A` are the first 8 bytes in the `PNG` signature (`PNG\\r\\n0x1A\\n`).\n\n    iex> ExImageInfo.info  >, :png\n    nil\n    iex> ExImageInfo.info  >, :webp\n    {\"image/webp\", 123, 456, \"webpVP8L\"}\n\nThe signature part of a png it is now enough to get the type (it check also the IHDR field, just before the width and height).\n\nUsually it is used as:\n\n    ExImageInfo.info File.read!(\"path/to/image.gif\"), :gif\n    # {\"image/gif\", 1920, 1080, \"GIF87a\"}\n\n    maybe_png_binary |> ExImageInfo.info :png\n    # nil","ref":"ExImageInfo.html#info/2-examples"},{"type":"function","title":"ExImageInfo.seems?/1","doc":"Detects the image format that seems to be the given binary (*guessed* version of `ExImageInfo.seems?/2`).\n\nReturns the valid [format](#module-formats) (atom) if it matches, `nil` otherwise.","ref":"ExImageInfo.html#seems?/1"},{"type":"function","title":"Examples - ExImageInfo.seems?/1","doc":"`38 42 50 53` are the first 4 bytes in the `PSD` signature (`8BPS`).\n\n    iex> ExImageInfo.seems?  >\n    :psd\n    iex> ExImageInfo.seems?  >\n    nil\n\n`ExImageInfo.seems?/2` and `ExImageInfo.seems?/1` does not necessarily needs a real image (as it is shown in the previous example) because it just checks the signature of every file format.\n\nUsually it is used as:\n\n    ExImageInfo.seems? File.read!(\"path/to/image.unknown\")\n    # :tiff\n\n    webp_full_binary |> ExImageInfo.seems?\n    # :webp","ref":"ExImageInfo.html#seems?/1-examples"},{"type":"function","title":"ExImageInfo.seems?/2","doc":"Detects if the given binary seems to be in the given image format.\n\nValid [formats](#module-formats) to be used.\n\nReturns `true` if the binary seems to be the format specified, `false` if it\nis not, and `nil` if the type is unsupported.","ref":"ExImageInfo.html#seems?/2"},{"type":"function","title":"Examples - ExImageInfo.seems?/2","doc":"`89 50 4E 47 0D 0A 1A 0A` are the first 8 bytes in the `PNG` signature (`PNG\\r\\n0x1A\\n`).\n\n    iex> ExImageInfo.seems?  >, :png\n    true\n    iex> ExImageInfo.seems?  >, :webp\n    false\n\n`ExImageInfo.seems?/2` and `ExImageInfo.seems?/1` does not necessarily needs a real image (as it is shown in the previous example) because it just checks the signature of every file format.\n\nUsually it is used as:\n\n    ExImageInfo.seems? File.read!(\"path/to/image.gif\"), :gif\n    # true\n\n    maybe_png_binary |> ExImageInfo.seems? :png\n    # false","ref":"ExImageInfo.html#seems?/2-examples"},{"type":"function","title":"ExImageInfo.type/1","doc":"Gets the mime-type and variant type for the given image binary (*guessed* version of `ExImageInfo.type/2`).\n\nPossible [Mime-types and Variants](#module-mime-types-and-variants) to be returned.\n\nReturns a 2-item tuple with the mime-type and the variant type when the binary matches, `nil` otherwise.","ref":"ExImageInfo.html#type/1"},{"type":"function","title":"Examples - ExImageInfo.type/1","doc":"iex> ExImageInfo.type  >\n    {\"image/psd\", \"PSD\"}\n    iex> ExImageInfo.type  >\n    nil\n\nUsually it is used as:\n\n    ExImageInfo.type File.read!(\"path/to/image.unknown\")\n    # {\"image/tiff\", \"TIFFMM\"}\n\n    webp_full_binary |> ExImageInfo.type\n    # {\"image/webp\", \"webpVP8\"}","ref":"ExImageInfo.html#type/1-examples"},{"type":"function","title":"ExImageInfo.type/2","doc":"Gets the mime-type and variant type for the given image format and binary.\n\nPossible [Mime-types and Variants](#module-mime-types-and-variants) to be returned.\n\nValid [formats](#module-formats) to be used.\n\nReturns a 2-item tuple with the mime-type and the variant type when the binary matches, `nil` otherwise.","ref":"ExImageInfo.html#type/2"},{"type":"function","title":"Examples - ExImageInfo.type/2","doc":"`89 50 4E 47 0D 0A 1A 0A` are the first 8 bytes in the `PNG` signature (`PNG\\r\\n0x1A\\n`).\n\n    iex> ExImageInfo.type  >, :png\n    nil\n    iex> ExImageInfo.type  >, :webp\n    {\"image/webp\", \"webpVP8L\"}\n\nThe signature part of a png it is now enough to get the type (it check also the IHDR field, just before the width and height).\n\nUsually it is used as:\n\n    ExImageInfo.type File.read!(\"path/to/image.gif\"), :gif\n    # {\"image/gif\", \"GIF87a\"}\n\n    maybe_png_binary |> ExImageInfo.type :png\n    # nil","ref":"ExImageInfo.html#type/2-examples"},{"type":"type","title":"ExImageInfo.image_format/0","doc":"The supported image formats","ref":"ExImageInfo.html#t:image_format/0"},{"type":"extras","title":"README","doc":"# README\n\n# ExImageInfo\n\n[![Elixir](https://img.shields.io/badge/made_in-elixir-9900cc.svg?style=flat-square)](http://elixir-lang.org) [![License](https://img.shields.io/badge/license-MIT-blue.svg?style=flat-square)](https://raw.githubusercontent.com/Group4Layers/ex_image_info/master/LICENSE.md)        \n\nExImageInfo is an Elixir library to parse images (binaries) and get the dimensions (size), detected mime-type and overall validity for a set of image formats. It is the fastest and supports multiple formats.\n\nOnline tools: [![Build Status](https://travis-ci.org/Group4Layers/ex_image_info.svg?branch=master)](https://travis-ci.org/Group4Layers/ex_image_info) [![Coverage Status](https://coveralls.io/repos/github/Group4Layers/ex_image_info/badge.svg?branch=master)](https://coveralls.io/github/Group4Layers/ex_image_info?branch=master) [![SourceLevel](https://app.sourcelevel.io/github/Group4Layers/-/ex_image_info.svg)](https://app.sourcelevel.io/github/Group4Layers/-/ex_image_info) [![Inline docs](http://inch-ci.org/github/Group4Layers/ex_image_info.svg)](http://inch-ci.org/github/Group4Layers/ex_image_info)\n\n### [GitHub repo](https://github.com/Group4Layers/ex_image_info) &nbsp;&nbsp; [Docs](https://group4layers.github.io/ex_image_info) &nbsp;&nbsp; [Hex.pm package](https://hex.pm/packages/ex_image_info)","ref":"readme.html"},{"type":"extras","title":"Table of Contents - README","doc":"1. [Description](#description)\n1. [Installation](#installation)\n1. [Examples](#examples)\n1. [Benchmarks](#benchmarks)\n1. [Design decisions](#design-decisions)\n1. [Acknowledgments](#acknowledgments)\n1. [Author](#author)\n1. [Contributors](#contributors)\n1. [ChangeLog](#changelog)\n1. [License](#license)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Description - README","doc":"Main module that checks and gets if a binary seems to be an image (specific\nformat), the mime-type (and variant detected) and the dimensions of the image\n(based on the type).\n\nIt has convention functions to guess the type of an image by trying the formats\nsupported by the library.\n\n#","ref":"readme.html#description"},{"type":"extras","title":"Main features - README","doc":"- Check the validity of binary by providing a specific image format*.\n- Guess the validity of an image*.\n- Get the mime-type and variant type by providing a specific format.\n- Guess the mime-type and variant type of an image.\n- Get the dimensions of an image by providing a specific format.\n- Guess the dimensions of an image.\n\n*Note: both cases as a general overview (partially checked).\n\n#","ref":"readme.html#main-features"},{"type":"extras","title":"Formats - README","doc":"Supported formats (image type to be parsed as):\n- `:bmp`\n- `:gif`\n- `:ico` (new in `v0.2.0`)\n- `:jpeg`\n- `:jpg` (alias of `jpeg` in `v0.2.3`)\n- `:jp2` (new in `v0.2.0`)\n- `:png`\n- `:pnm` (new in `v0.2.0`)\n- `:psd`\n- `:tiff`\n- `:webp` (VP8X animated in `v0.2.4`)","ref":"readme.html#formats"},{"type":"extras","title":"Mime-types and Variants - README","doc":"The image variant type is an invented string to identify the\ntype of format recognized by this library (more specific than the\nmime-type).\n\nEach mime-type can be linked to at least one variant type:\n\n| mime-type                 | variant type | description        |\n| ------------------------- | ------------ | ------------------ |\n| `image/bmp`               | `BMP`        |                    |\n| `image/gif`               | `GIF87a`     | 87a gif spec       |\n| `image/gif`               | `GIF89a`     | 89a gif spec       |\n| `image/x-icon`            | `ICO`        |                    |\n| `image/jpeg`              | `baseJPEG`   | baseline JPEG      |\n| `image/jpeg`              | `progJPEG`   | progressive JPEG   |\n| `image/jp2`               | `JP2`        | JPEG2000           |\n| `image/png`               | `PNG`        |                    |\n| `image/x-portable-anymap` | `PNMpbm`     | Portable BitMap    |\n| `image/x-portable-anymap` | `PNMpgm`     | Portable GrayMap   |\n| `image/x-portable-anymap` | `PNMppm`     | Portable PixMap    |\n| `image/psd`               | `PSD`        |                    |\n| `image/tiff`              | `TIFFII`     | II variant         |\n| `image/tiff`              | `TIFFMM`     | MM variant         |\n| `image/webp`              | `webpVP8`    | lossy              |\n| `image/webp`              | `webpVP8L`   | lossless           |\n| `image/webp`              | `webpVP8X`   | animated           |\n\nThe variant type is created just to provide a bit more of information\nfor every image format (if applicable).\n\n*Note*: `:ico` returns the dimensions of the largest image contained (not the first found).\n\nThe guessing functions try to detect the format of the binary by testing every available type based on its global usage (popularity, [usage of image file formats](https://w3techs.com/technologies/overview/image_format/all), but still keeping the `:png` as the first one):\n- `:png`, `:jpeg`, `:gif`, `:bmp`, `:ico`, `:tiff`, `:webp`, `:psd`, `:jp2`, `:pnm`\n\n**Warnings:**\n\n- Use with caution the formats *ico*, *jp2* and the family *pnm*. They are implemented without following other libraries (just reading the specs - sometimes working with old drafts like *jp2*). You can support this library by providing more tests and image *fixtures* or requesting other variants to be tested.","ref":"readme.html#mime-types-and-variants"},{"type":"extras","title":"Installation - README","doc":"Add `ex_image_info` to your list of dependencies in `mix.exs`.\n\nFrom Hex:\n\n```elixir\n  def deps do\n    [\n      # ...\n      {:ex_image_info, \"~> 0.2.4\"},\n    ]\n  end\n```\n\nOr GitHub:\n\n```elixir\n  def deps do\n    [\n      # ...\n      {:ex_image_info, github: \"Group4Layers/ex_image_info\"},\n    ]\n  end\n```\n\nThen, use it:\n\n```elixir\nrequire ExImageInfo\n# ExImageInfo.seems? ...\n```","ref":"readme.html#installation"},{"type":"extras","title":"Examples - README","doc":"The following examples are run with the latest version of the library under the next environment:\n\n```elixir\nErlang/OTP 19 [erts-8.0.2] [source] [64-bit] [smp:8:8] [async-threads:10] [hipe] [kernel-poll:false]\n\nInteractive Elixir (1.3.2) - press Ctrl+C to exit (type h() ENTER for help)\niex(1)>\n```\n\n#","ref":"readme.html#examples"},{"type":"extras","title":"Feature `seems?` - README","doc":"`89 50 4E 47 0D 0A 1A 0A` are the first 8 bytes in the `PNG` signature (`PNG\\\\r\\\\n0x1A\\\\n`).\n\n```elixir\niex(1)> ExImageInfo.seems?  >, :png\ntrue\n\niex(2)> ExImageInfo.seems?  >, :webp\nfalse\n```\n\n`ExImageInfo.seems?/2` and `ExImageInfo.seems?/1` does not necessarily needs a real image (as it is shown in the previous example) because it just checks the signature of every file format.\n\nUsually it is used as:\n\n```elixir\niex(1)> ExImageInfo.seems? File.read!(\"path/to/image.gif\"), :gif\ntrue\n\niex(2)> maybe_png_binary |> ExImageInfo.seems? :png\nfalse\n```\n\n`38 42 50 53` are the first 4 bytes in the `PSD` signature (`8BPS`).\n\n```elixir\niex(1)> ExImageInfo.seems?  >\n:psd\n\niex(2)> ExImageInfo.seems?  >\nnil\n```\n\n`ExImageInfo.seems?/2` and `ExImageInfo.seems?/1` does not necessarily needs a real image (as it is shown in the previous example) because it just checks the signature of every file format.\n\nUsually it is used as:\n\n```elixir\niex(1)> ExImageInfo.seems? File.read!(\"path/to/image.unknown\")\n:tiff\n\niex(2)> webp_full_binary |> ExImageInfo.seems?\n:webp\n```\n\n#","ref":"readme.html#feature-seems"},{"type":"extras","title":"Feature `type` - README","doc":"`89 50 4E 47 0D 0A 1A 0A` are the first 8 bytes in the `PNG` signature (`PNG\\\\r\\\\n0x1A\\\\n`).\n\n```elixir\niex(1)> ExImageInfo.type  >, :png\nnil\n\niex(2)> ExImageInfo.type  >, :webp\n{\"image/webp\", \"webpVP8L\"}\n```\n\nThe signature part of a png it is now enough to get the type (it check also the IHDR field, just before the width and height).\n\nUsually it is used as:\n\n```elixir\niex(1)> ExImageInfo.type File.read!(\"path/to/image.gif\"), :gif\n{\"image/gif\", \"GIF87a\"}\n\niex(2)> maybe_png_binary |> ExImageInfo.type :png\nnil\n```\n\nThe *guessed* version.\n\n```elixir\niex(1)> ExImageInfo.type  >\n{\"image/psd\", \"PSD\"}\n\niex(2)> ExImageInfo.type  >\nnil\n```\n\nUsually it is used as:\n\n```elixir\niex(1)> ExImageInfo.type File.read!(\"path/to/image.unknown\")\n{\"image/tiff\", \"TIFFMM\"}\n\niex(2)> webp_full_binary |> ExImageInfo.type\n{\"image/webp\", \"webpVP8\"}\n```\n\n#","ref":"readme.html#feature-type"},{"type":"extras","title":"Feature `info` - README","doc":"`89 50 4E 47 0D 0A 1A 0A` are the first 8 bytes in the `PNG` signature (`PNG\\\\r\\\\n0x1A\\\\n`).\n\n```elixir\niex(1)> ExImageInfo.info  >, :png\nnil\n\niex(2)> ExImageInfo.info  >, :webp\n{\"image/webp\", 123, 456, \"webpVP8L\"}\n```\n\nThe signature part of a png it is now enough to get the type (it check also the IHDR field, just before the width and height).\n\nUsually it is used as:\n\n```elixir\niex(1)> ExImageInfo.info File.read!(\"path/to/image.gif\"), :gif\n{\"image/gif\", 1920, 1080, \"GIF87a\"}\n\niex(2)> maybe_png_binary |> ExImageInfo.info :png\nnil\n```\n\n```elixir\niex(1)> ExImageInfo.info  >\nnil\n\niex(2)> ExImageInfo.info  >\n{\"image/psd\", 12, 10, \"PSD\"}\n```\n\nUsually it is used as:\n\n```elixir\niex(1)> ExImageInfo.info File.read!(\"path/to/image.unknown\")\n{\"image/tiff\", 128, 256, \"TIFFMM\"}\n\niex(2)> webp_full_binary |> ExImageInfo.info\n{\"image/webp\", 20, 100, \"webpVP8\"}\n```","ref":"readme.html#feature-info"},{"type":"extras","title":"Benchmarks - README","doc":"Group4Layers developed the fastest elixir library to obtain the dimensions of the images (binary data parsed). Also, it excels supporting the maximum number of image formats. All without dependencies.\n\n![ExImageInfo Benchmarks](assets/ex_image_info_benchmarks.png)\n\n(The image wouldn't be included in the package).","ref":"readme.html#benchmarks"},{"type":"extras","title":"Design decisions - README","doc":"#","ref":"readme.html#design-decisions"},{"type":"extras","title":"Why `seems?` and not `magic?` or `signature?`? - README","doc":"Because for some formats it is enough with the [*magic\nnumber*](https://en.wikipedia.org/wiki/Magic_number_(programming)) or the\nsignature to get the type (image format that \"starts\" correctly), but in other\ncases it is an algorithm a bit more complex to see if the binary seems\ncorrect. Therefore, *seems* it is more general (than getting the *magic\nnumber*) and it will provide a \"quick overview\" of the validity of the\nbinary.\n\n#","ref":"readme.html#why-seems-and-not-magic-or-signature"},{"type":"extras","title":"Why returning the mime-type and variant type when getting the dimensions (`info`)? - README","doc":"Because both types (variant if applicable) are necessary to obtain the width and height\nof the binary for a specific format. In case it is required both the type (and variant) and the dimensions it is not necessary to call two functions (and re-parse part or completely the binary). Therefore, to get the dimensions it is obtained the types and all the information is returned in one step.\n\n#","ref":"readme.html#why-returning-the-mime-type-and-variant-type-when-getting-the-dimensions-info"},{"type":"extras","title":"Renamed from ExImageSize to ExImageInfo - README","doc":"Although it has been released since the very first version with the name ExImageInfo,\nthis library was previously known as ExImageSize, but it is preferable to have a name\nless restricted. Nowadays it can get information about the type and the dimensions (size),\nbut in a future it could increase the amount of info to extract from an image.","ref":"readme.html#renamed-from-eximagesize-to-eximageinfo"},{"type":"extras","title":"Acknowledgments - README","doc":"This idea comes from libraries that I have used in other platforms and/or languages. Algorithms and some concepts are picked and based on parts of the following:\n- image-size (JavaScript) - *Aditya Yadav*\n- imagesize (Ruby) - *Keisuke Minami*\n- fastimage (Ruby) - *Stephen Sykes*\n\nThanks to them.","ref":"readme.html#acknowledgments"},{"type":"extras","title":"Author - README","doc":"nozalr   (Group4Layers®).","ref":"readme.html#author"},{"type":"extras","title":"Contributors - README","doc":"See [CONTRIBUTORS](contributors.html) for more information.\n\n*GitHub readers (repo, no docs): [CONTRIBUTORS.md](CONTRIBUTORS.md).*","ref":"readme.html#contributors"},{"type":"extras","title":"ChangeLog - README","doc":"See [CHANGELOG](changelog.html) for more information.\n\n*GitHub readers (repo, no docs): [CHANGELOG.md](CHANGELOG.md).*","ref":"readme.html#changelog"},{"type":"extras","title":"License - README","doc":"ExImageInfo source code is released under the MIT License.\n\nSee [LICENSE](license.html) for more information.\n\n*GitHub readers (repo, no docs): [LICENSE.md](LICENSE.md).*","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"# LICENSE\n\nMIT License\n\nCopyright (c) 2016   nozalr   (Group4Layers®)\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"v0.2.4 (2018-11-24) - CHANGELOG","doc":"**Enhancements**\n\n- By request of a GitHub user: support for another variant of webp\n- Studied and integrated the webpVP8X format (bitstream animated)\n- Added 2 new tests for animated photos: gif and webp vp8x","ref":"changelog.html#v0-2-4-2018-11-24"},{"type":"extras","title":"v0.2.3 (2018-05-21) - CHANGELOG","doc":"**Enhancements:**\n\n- By request of a GitHub user: added the type *jpg* as an alias of *jpeg*.","ref":"changelog.html#v0-2-3-2018-05-21"},{"type":"extras","title":"v0.2.2 (2017-11-04) - CHANGELOG","doc":"**News:**\n\n- Docs are in the official repo, not in gh-pages branch.\n- Added inch-ci and ebertapp static analysis online tools (0 issues).\n- Repository promoted to the Group4Layers organization.\n- New \"patch\" version to include the changes.","ref":"changelog.html#v0-2-2-2017-11-04"},{"type":"extras","title":"v0.2.1 (2017-11-03) - CHANGELOG","doc":"**Enhancements:**\n\n- Code is improved following credo, solving:\n  - 5 software design suggestions.\n  - 34 code readability issues.\n  - 2 refactoring opportunities.\n  - 2 consistency issues.\n- Clean code: removed superfluous comments and refactored def to defp when applicable.\n\n**News:**\n\n- Benchmarks are performed. An image with charts is included to compare famous elixir libraries. ExImageInfo always outperforms.\n- Online tools applied (TravisCI and Coveralls). Badges included.\n- Added ebertapp static analysis online tool.\n- Repository promoted to Group4Layers organization.\n- New \"patch\" version to include the changes.","ref":"changelog.html#v0-2-1-2017-11-03"},{"type":"extras","title":"v0.2.0 (2017-06-17) - CHANGELOG","doc":"**Warnings:**\n\n- Use with caution the formats *ico*, *jp2* and the family *pnm*. They are implemented without following other libraries (just reading the specs - sometimes working with old drafts like *jp2*). You can support this library by providing more tests and image *fixtures* or requesting other variants to be tested.\n\n**Enhancements:**\n\n- The guessing function is ordered by global usage [usage of image file formats](https://w3techs.com/technologies/overview/image_format/all), but still keeping *png* as the first one.\n- Added support for *ico*, *jp2* (*jpeg 2000*) and the collection of *pnm* (*pbm*, *pgm* and *ppm*)\n- *ico* gets the dimensions of the largest image contained (not the first found)\n\n**Statistics:**\n\n- 54 TDD Tests\n- Code coverage of 98.3%\n- 10 image formats supported\n\n**News:**\n\n- New minor version (`0.2.0`) due to the three new image formats supported.","ref":"changelog.html#v0-2-0-2017-06-17"},{"type":"extras","title":"v0.1.1 (2016-08-12) - CHANGELOG","doc":"**Enhancements:**\n\n- Warnings corrected (compiling)\n\n**Statistics:**\n\n- 34 TDD Tests\n- Code coverage of 97.6%\n- 7 image formats supported\n\n**News:**\n\n- Initial release (published) + Docs (gh-pages)","ref":"changelog.html#v0-1-1-2016-08-12"},{"type":"extras","title":"v0.1.0 (2016-08-11) - CHANGELOG","doc":"**News:**\n\n- Initial release (pre-publish)","ref":"changelog.html#v0-1-0-2016-08-11"},{"type":"extras","title":"CONTRIBUTORS","doc":"# CONTRIBUTORS\n\nnozalr","ref":"contributors.html"}],"content_type":"text/markdown"}